pub struct ResourceTemplate { /* private fields */ }Expand description
A template for resources that can be dynamically generated
Implementations
Sourceimpl ResourceTemplate
impl ResourceTemplate
Sourcepub fn new(uri_template: impl Into<String>) -> Self
pub fn new(uri_template: impl Into<String>) -> Self
Create a new resource template with the given URI pattern
Sourcepub fn with_list<F, Fut>(self, callback: F) -> Self
pub fn with_list<F, Fut>(self, callback: F) -> Self
Add a callback to list all resources matching this template
Sourcepub fn with_completion(
self,
variable: impl Into<String>,
completable: impl Completable<Input = str, Output = String> + 'static,
) -> Self
pub fn with_completion( self, variable: impl Into<String>, completable: impl Completable<Input = str, Output = String> + 'static, ) -> Self
Add a completion callback for a template variable
Sourcepub fn uri_template(&self) -> &str
pub fn uri_template(&self) -> &str
Get the URI template pattern
Sourcepub fn list_callback(&self) -> Option<&dyn ListResourcesCallback>
pub fn list_callback(&self) -> Option<&dyn ListResourcesCallback>
Get the list callback if one exists
Sourcepub fn complete_callback(
&self,
variable: &str,
) -> Option<&dyn Completable<Input = str, Output = String>>
pub fn complete_callback( &self, variable: &str, ) -> Option<&dyn Completable<Input = str, Output = String>>
Get the completion callback for a variable if one exists